.. _optimize_indexing:

laue_dials.optimize_indexing
============================

Introduction
------------

.. python_string:: laue_dials.command_line.optimize_indexing.help_message

Basic parameters
----------------

.. phil:: laue_dials.command_line.optimize_indexing.working_phil
   :expert-level: 0
   :attributes-level: 0


Full parameter definitions
--------------------------

.. phil:: laue_dials.command_line.optimize_indexing.working_phil
   :expert-level: 2
   :attributes-level: 2
